Crate turn_server

Crate turn_server 

Modules

api
codec
Session Traversal Utilities for NAT (STUN)
config
handler
prelude
prometheus
server
service
statistics

Functions

start_server
In order to let the integration test directly use the turn-server crate and start the server, a function is opened to replace the main function to directly start the server.