#[repr(u32)]pub enum RequestedTransport {
Tcp = 100_663_296,
Udp = 285_212_672,
}Expand description
This attribute is used by the client to request a specific transport protocol for the allocated transport address.
The Protocol field specifies the desired protocol. The codepoints used in this field are taken from those allowed in the Protocol field in the IPv4 header and the NextHeader field in the IPv6 header [Protocol-Numbers]. This specification only allows the use of codepoint 17 (User Datagram Protocol).
The RFFU field MUST be set to zero on transmission and MUST be ignored on reception. It is reserved for future uses.
Variants