pub struct Prometheus {
pub listen: SocketAddr,
pub ssl: Option<Ssl>,
}Fields
listen: SocketAddrprometheus server listen
This option specifies the prometheus server binding address used to expose the metrics.
ssl: Option<Ssl>ssl configuration
This option specifies the ssl configuration for the prometheus server.