Module session

Module session 

Modules

ports

Structs

Endpoint
The endpoint used to record the current session.
Identifier
The identifier of the session.
ReadLock
Used to lengthen the timing of the release of a readable lock guard and to provide a more convenient way for external access to the lock’s internal data.
SessionManager
SessionManagerOptions
Table
The default HashMap is created without allocating capacity. To improve performance, the turn server needs to pre-allocate the available capacity.
Timer
A specially optimised timer.

Enums

Session
turn session information.

Constants

DEFAULT_SESSION_LIFETIME
Default session lifetime in seconds (10 minutes)