Module session
turn_
server
4.1.1
Module session
Module Items
Modules
Structs
Enums
Constants
In turn_
server::
service
turn_server
::
service
Module
session
Modules

ports
Structs

Identifier
The identifier of the session.
Read
Lock
Used to lengthen the timing of the release of a readable lock guard and to provide a more convenient way for external access to the lock’s internal data.
Session
Manager
Session
Manager
Options
Table
The default HashMap is created without allocating capacity. To improve performance, the turn server needs to pre-allocate the available capacity.
Timer
A specially optimised timer.
Enums

Session
turn session information.
Constants

DEFAULT_
SESSION_
LIFETIME
Default session lifetime in seconds (10 minutes)